"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@credo-ts/core");
const lodash_startcase_1 = __importDefault(require("lodash.startcase"));
const types_1 = require("../../types");
const moment_1 = __importDefault(require("moment"));
const TypeEnums_1 = require("../../types/TypeEnums");
class LocalizedAttribute extends core_1.CredentialPreviewAttribute {
    constructor(options, overlayOptions, language) {
        super(options);
        this.type = overlayOptions.type;
        this.characterEncoding = overlayOptions.characterEncoding;
        this.standard = overlayOptions.standard;
        this.format = overlayOptions.format;
        this.information = overlayOptions.information?.[language];
        this.label = overlayOptions.label?.[language];
    }
    get formattedLabel() {
        return this.label ?? (0, lodash_startcase_1.default)(this.name);
    }
    get formattedValue() {
        switch (this.type) {
            case types_1.CaptureBaseAttributeType.DateTime:
            case types_1.CaptureBaseAttributeType.DateInt:
                if (this.standard === TypeEnums_1.OverlayStandard.ISO1989) {
                    const year = this.value.slice(0, 4);
                    const month = this.value.slice(4, 6);
                    const day = this.value.slice(6, 8);
                    return (0, moment_1.default)(`${year}-${month}-${day}`).toISOString();
                }
                else {
                    return (0, moment_1.default)(this.value).toISOString();
                }
            default:
                return this.value;
        }
    }
    toJSON() {
        return { ...super.toJSON(), format: this.format, information: this.information, label: this.label };
    }
}
exports.default = LocalizedAttribute;
