"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OverlayBundleResolver = exports.BaseOverlayBundleResolver = void 0;
const constants_1 = require("../constants");
const types_1 = require("../types");
const utils_1 = require("../utils");
const credential_definition_1 = require("../utils/credential-definition");
const lodash_startcase_1 = __importDefault(require("lodash.startcase"));
class BaseOverlayBundleResolver {
    /**
     * Get the log value.
     */
    get log() {
        return this._log;
    }
    /**
     * Sets the log value.
     * @param value - The new value for the log.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    set log(value) {
        this._log = value;
    }
}
exports.BaseOverlayBundleResolver = BaseOverlayBundleResolver;
class OverlayBundleResolver extends BaseOverlayBundleResolver {
    constructor(bundles = {}) {
        super();
        this.bundles = {};
        for (const credentialDefinitionId in bundles) {
            const bundle = bundles[credentialDefinitionId];
            try {
                if (typeof bundle === 'string') {
                    this.bundles[credentialDefinitionId] = bundle;
                }
                else {
                    this.bundles[credentialDefinitionId] = new types_1.OverlayBundle(credentialDefinitionId, bundle);
                }
            }
            catch (error) {
                this.log?.error(`Error parsing bundle for ${credentialDefinitionId}`, error);
            }
        }
    }
    getDefaultBundle(params) {
        const { identifiers, metadata, language } = params;
        const defaultMetaOverlay = {
            capture_base: '',
            type: types_1.OverlayType.Meta10,
            name: metadata?.credentialAlias ??
                (0, lodash_startcase_1.default)(metadata?.credentialId ?? (0, credential_definition_1.parseCredDefFromId)(identifiers?.credentialDefinitionId, identifiers?.schemaId)),
            issuer: metadata?.connectionAlias || metadata?.connectionId || 'Unknown Contact',
            language: language ?? constants_1.defaultBundleLanguage,
            description: '',
            credential_help_text: '',
            credential_support_url: '',
            issuer_description: '',
            issuer_url: '',
        };
        const colorHash = defaultMetaOverlay?.name ?? defaultMetaOverlay?.issuer ?? 'default';
        const defaultBrandingoOverlay = {
            capture_base: '',
            type: types_1.OverlayType.Branding10,
            primary_background_color: (0, utils_1.generateColor)(colorHash)
        };
        const bundle = new types_1.OverlayBundle(identifiers?.credentialDefinitionId, {
            capture_base: {
                attributes: {},
                classification: '',
                type: types_1.OverlayType.CaptureBase10,
                flagged_attributes: [],
            },
            overlays: [defaultMetaOverlay, defaultBrandingoOverlay],
        });
        return bundle;
    }
    resolveDefaultBundle(params) {
        const bundle = this.getDefaultBundle(params);
        return Promise.resolve(bundle);
    }
    resolveBundle(params) {
        const { identifiers } = params;
        for (const identifier of [identifiers?.credentialDefinitionId, identifiers?.schemaId, identifiers?.templateId]) {
            if (identifier) {
                let bundle = this.bundles[identifier];
                // If it is a string, it is a reference/alias to another one bundle
                if (typeof bundle === 'string') {
                    // Is this guaranteed to be a only one level deep?
                    bundle = this.bundles[bundle];
                }
                return Promise.resolve(bundle);
            }
        }
        return Promise.resolve(undefined);
    }
}
exports.OverlayBundleResolver = OverlayBundleResolver;
