"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _OverlayBundle_instances, _OverlayBundle_processMetadata, _OverlayBundle_processLanguages, _OverlayBundle_processOverlayAttributes, _OverlayBundle_processInformationForAttribute, _OverlayBundle_processLabelForAttribute, _OverlayBundle_processCharacterEncodingForAttribute, _OverlayBundle_processStandardForAttribute, _OverlayBundle_processFormatForAttribute, _OverlayBundle_overlaysForType;
Object.defineProperty(exports, "__esModule", { value: true });
const OverlayTypeMap_1 = __importDefault(require("../OverlayTypeMap"));
const BaseOverlay_1 = __importDefault(require("../base/BaseOverlay"));
const BrandingOverlay_1 = __importDefault(require("../branding/BrandingOverlay"));
const LegacyBrandingOverlay_1 = __importDefault(require("../branding/LegacyBrandingOverlay"));
const CaptureBase_1 = __importDefault(require("../capture-base/CaptureBase"));
class OverlayBundle {
    constructor(credentialDefinitionId, bundle) {
        _OverlayBundle_instances.add(this);
        this.credentialDefinitionId = credentialDefinitionId;
        this.captureBase = new CaptureBase_1.default(bundle.capture_base);
        this.overlays = bundle.overlays
            .filter((overlay) => !overlay.type.startsWith('aries/overlays/branding/'))
            .map((overlay) => {
            const OverlayClass = (OverlayTypeMap_1.default.get(overlay.type) || BaseOverlay_1.default);
            return new OverlayClass(overlay);
        });
        this.overlays.push(...bundle.overlays
            .filter((overlay) => overlay.type === 'aries/overlays/branding/0.1')
            .map((overlay) => {
            const OverlayClass = (OverlayTypeMap_1.default.get(overlay.type) ||
                LegacyBrandingOverlay_1.default);
            return new OverlayClass(credentialDefinitionId, overlay);
        }));
        this.overlays.push(...bundle.overlays
            .filter((overlay) => overlay.type === 'aries/overlays/branding/1.0')
            .map((overlay) => {
            const OverlayClass = (OverlayTypeMap_1.default.get(overlay.type) || BrandingOverlay_1.default);
            return new OverlayClass(credentialDefinitionId, overlay);
        }));
        this.languages = __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processLanguages).call(this);
        this.metadata = __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processMetadata).call(this);
        this.attributes = __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processOverlayAttributes).call(this);
        this.flaggedAttributes = this.attributes.filter((attribute) => this.captureBase.flaggedAttributes.includes(attribute.name));
    }
    get branding() {
        return __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'aries/overlays/branding/1.0')[0];
    }
    getAttribute(name) {
        return this.attributes.find((attribute) => attribute.name === name);
    }
    getFlaggedAttribute(name) {
        return this.flaggedAttributes.find((attribute) => attribute.name === name);
    }
}
_OverlayBundle_instances = new WeakSet(), _OverlayBundle_processMetadata = function _OverlayBundle_processMetadata() {
    const metadata = {
        name: {},
        description: {},
        credentialHelpText: {},
        credentialSupportUrl: {},
        issuer: {},
        issuerDescription: {},
        issuerUrl: {},
        watermark: {},
    };
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/meta/1.0')) {
        const language = overlay.language ?? 'en';
        const { name, description, credentialHelpText, credentialSupportUrl, issuer, issuerDescription, issuerUrl, watermark, } = overlay;
        if (name) {
            metadata.name[language] = name;
        }
        if (description) {
            metadata.description[language] = description;
        }
        if (credentialHelpText) {
            metadata.credentialHelpText[language] = credentialHelpText;
        }
        if (credentialSupportUrl) {
            metadata.credentialSupportUrl[language] = credentialSupportUrl;
        }
        if (issuer) {
            metadata.issuer[language] = issuer;
        }
        if (issuerDescription) {
            metadata.issuerDescription[language] = issuerDescription;
        }
        if (issuerUrl) {
            metadata.issuerUrl[language] = issuerUrl;
        }
        if (watermark) {
            metadata.watermark[language] = watermark;
        }
    }
    return metadata;
}, _OverlayBundle_processLanguages = function _OverlayBundle_processLanguages() {
    const languages = [];
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/meta/1.0')) {
        const language = overlay.language;
        if (language && !languages.includes(language)) {
            languages.push(language);
        }
    }
    languages.sort((a, b) => a.localeCompare(b));
    return languages;
}, _OverlayBundle_processOverlayAttributes = function _OverlayBundle_processOverlayAttributes() {
    const attributes = [];
    const attributeMap = new Map(Object.entries(this.captureBase.attributes));
    for (const [name, type] of attributeMap) {
        attributes.push({
            name,
            type,
            information: __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processInformationForAttribute).call(this, name),
            label: __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processLabelForAttribute).call(this, name),
            characterEncoding: __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processCharacterEncodingForAttribute).call(this, name),
            standard: __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processStandardForAttribute).call(this, name),
            format: __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_processFormatForAttribute).call(this, name),
        });
    }
    return attributes;
}, _OverlayBundle_processInformationForAttribute = function _OverlayBundle_processInformationForAttribute(key) {
    const information = {};
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/information/1.0')) {
        if (overlay.attributeInformation?.[key]) {
            const language = overlay.language ?? 'en';
            information[language] = overlay.attributeInformation[key];
        }
    }
    return information;
}, _OverlayBundle_processLabelForAttribute = function _OverlayBundle_processLabelForAttribute(key) {
    const label = {};
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/label/1.0')) {
        if (overlay.attributeLabels?.[key]) {
            const language = overlay.language ?? 'en';
            label[language] = overlay.attributeLabels[key];
        }
    }
    return label;
}, _OverlayBundle_processCharacterEncodingForAttribute = function _OverlayBundle_processCharacterEncodingForAttribute(key) {
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/character_encoding/1.0')) {
        if (overlay.attributeCharacterEncoding?.[key]) {
            return overlay.attributeCharacterEncoding[key];
        }
    }
    return;
}, _OverlayBundle_processStandardForAttribute = function _OverlayBundle_processStandardForAttribute(key) {
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/standard/1.0')) {
        if (overlay.attributeStandards?.[key]) {
            return overlay.attributeStandards[key];
        }
    }
    return;
}, _OverlayBundle_processFormatForAttribute = function _OverlayBundle_processFormatForAttribute(key) {
    for (const overlay of __classPrivateFieldGet(this, _OverlayBundle_instances, "m", _OverlayBundle_overlaysForType).call(this, 'spec/overlays/format/1.0')) {
        if (overlay.attributeFormats?.[key]) {
            return overlay.attributeFormats[key];
        }
    }
    return;
}, _OverlayBundle_overlaysForType = function _OverlayBundle_overlaysForType(type) {
    return this.overlays.filter((overlay) => overlay.type === type);
};
exports.default = OverlayBundle;
