"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
const utils_1 = require("../../../utils");
const Issuer_1 = __importDefault(require("../../../ui/components/common/Issuer"));
const Logo_1 = __importDefault(require("../../../ui/components/common/Logo"));
const Name_1 = __importDefault(require("../../../ui/components/common/Name"));
const Status_1 = __importDefault(require("../../components/card/Status"));
const Watermark_1 = __importDefault(require("../../../ui/components/common/Watermark"));
const Primary_1 = __importDefault(require("../../components/card/body/Primary"));
const Secondary_1 = __importDefault(require("../../components/card/body/Secondary"));
const Claim_1 = __importDefault(require("../../components/card/claim/Claim"));
const utils_2 = require("../../components/card/utils");
const credentialTheme_1 = require("../../contexts/credentialTheme");
const Card = ({ connectionId, credentialId, status, credential, children }) => {
    const { color } = (0, credentialTheme_1.useCredentialTheme)();
    const { width: windowWidth } = (0, react_native_1.useWindowDimensions)();
    let styles = (0, utils_2.createStyleSheet)(windowWidth);
    styles = {
        ...styles,
        container: {
            flexDirection: 'row',
            borderRadius: 10,
            ...styles.container,
        },
        primary: {
            ...styles.primary,
            backgroundColor: credential?.primaryBackgroundColor,
        },
        secondary: {
            ...styles.secondary,
            backgroundColor: credential?.secondaryBackgroundColor ?? credential?.primaryBackgroundColor,
            zIndex: +!!(credential?.backgroundImageSlice ?? credential?.secondaryBackgroundColor),
        },
        issuerText: {
            ...styles.issuerText,
            color: (0, utils_1.contrastColor)(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
        },
        nameText: {
            ...styles.nameText,
            color: (0, utils_1.contrastColor)(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
            fontWeight: 'bold',
        },
        claimText: {
            ...styles.claimText,
            color: (0, utils_1.contrastColor)(credential?.primaryBackgroundColor),
        },
        watermarkText: {
            ...styles.watermarkText,
            color: (0, utils_1.contrastColor)(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.lightGrey),
        },
    };
    return (<react_native_1.View style={styles.container}>
      <Logo_1.default source={credential?.logo} label={credential?.name ?? credential?.issuer ?? credentialId ?? connectionId} style={styles.logo}/>
      <Secondary_1.default source={(0, utils_1.toImageSource)(credential?.backgroundImageSlice)} style={styles.secondary} tint={!(credential?.backgroundImageSlice || credential?.secondaryBackgroundColor)}/>
      <Primary_1.default style={styles.primary}>
        <react_native_1.View style={styles.primaryChild}>
          <Issuer_1.default issuer={credential?.issuer ?? connectionId} textStyle={styles.issuerText}/>
          <Name_1.default name={credential?.name ?? credentialId} textStyle={styles.nameText}/>
          {children ?? (<>
              {credential?.primaryAttribute && (<Claim_1.default attribute={credential?.primaryAttribute} textStyle={styles.claimText}/>)}
              {credential?.secondaryAttribute && (<Claim_1.default attribute={credential?.secondaryAttribute} textStyle={styles.claimText}/>)}
            </>)}
        </react_native_1.View>
      </Primary_1.default>
      {credential?.watermark && (<Watermark_1.default watermark={credential?.watermark} style={styles.watermark} textStyle={styles.watermarkText}/>)}
      {status && <Status_1.default level={status} style={styles.status}/>}
    </react_native_1.View>);
};
exports.default = Card;
