"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusLevelEnum = void 0;
const react_native_1 = require("react-native");
const MaterialIcons_1 = __importDefault(require("react-native-vector-icons/MaterialIcons"));
const credentialTheme_1 = require("../../contexts/credentialTheme");
var StatusLevelEnum;
(function (StatusLevelEnum) {
    StatusLevelEnum["WARNING"] = "warning";
    StatusLevelEnum["ERROR"] = "error";
})(StatusLevelEnum || (exports.StatusLevelEnum = StatusLevelEnum = {}));
const Status = ({ level = undefined, style }) => {
    const { color } = (0, credentialTheme_1.useCredentialTheme)();
    const { width, height, position, top, right } = style ?? {};
    const borderRadius = 10;
    const styles = react_native_1.StyleSheet.create({
        container: {
            width,
            height,
            position,
            top,
            right,
            borderTopRightRadius: borderRadius,
            borderBottomLeftRadius: borderRadius,
            justifyContent: 'center',
            alignItems: 'center',
            zIndex: 2,
        },
    });
    const renderStatus = (level) => {
        switch (level) {
            case StatusLevelEnum.WARNING:
                return (<react_native_1.View style={[
                        styles.container,
                        {
                            backgroundColor: color.notification.warn,
                        },
                    ]}>
            <MaterialIcons_1.default style={{
                        color: color.semantic.warn,
                    }} size={0.7 * width} name={level}/>
          </react_native_1.View>);
            case StatusLevelEnum.ERROR:
                return (<react_native_1.View style={[
                        styles.container,
                        {
                            backgroundColor: color.notification.error,
                        },
                    ]}>
            <MaterialIcons_1.default style={{
                        color: color.semantic.error,
                    }} size={0.7 * width} name={level}/>
          </react_native_1.View>);
            default:
                return null;
        }
    };
    return (<react_native_1.View>
      {renderStatus(level)}
    </react_native_1.View>);
};
exports.default = Status;
