"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStyleSheet = exports.calculateSecondaryHeight = exports.calculateSecondaryWidth = exports.calculatePrimaryHeight = exports.calculatePrimaryWidth = exports.calculateLogoHeight = exports.calculateLogoWidth = exports.calculatePadding = void 0;
const react_native_1 = require("react-native");
const utils_1 = require("../../components/common/utils");
const constants_1 = require("./constants");
const calculatePadding = (width) => {
    return constants_1.PADDING_RATIO * width;
};
exports.calculatePadding = calculatePadding;
const calculateLogoWidth = (width) => {
    return constants_1.LOGO_RATIO * width;
};
exports.calculateLogoWidth = calculateLogoWidth;
const calculateLogoHeight = (width) => {
    return constants_1.LOGO_RATIO * width;
};
exports.calculateLogoHeight = calculateLogoHeight;
const calculatePrimaryWidth = (width) => {
    return constants_1.PRIMARY_RATIO * width;
};
exports.calculatePrimaryWidth = calculatePrimaryWidth;
const calculatePrimaryHeight = (width) => {
    return constants_1.HEIGHT_RATIO * width;
};
exports.calculatePrimaryHeight = calculatePrimaryHeight;
const calculateSecondaryWidth = (width) => {
    return constants_1.SECONDARY_RATIO * width;
};
exports.calculateSecondaryWidth = calculateSecondaryWidth;
const calculateSecondaryHeight = (width) => {
    return constants_1.HEIGHT_RATIO * width;
};
exports.calculateSecondaryHeight = calculateSecondaryHeight;
const createStyleSheet = (windowWidth) => {
    const baseStyles = (0, utils_1.createBaseStyleSheet)(windowWidth);
    const padding = (0, exports.calculatePadding)(windowWidth);
    const logoWidth = (0, exports.calculateLogoWidth)(windowWidth);
    const logoHeight = (0, exports.calculateLogoHeight)(windowWidth);
    const primaryWidth = (0, exports.calculatePrimaryWidth)(windowWidth);
    const primaryHeight = (0, exports.calculatePrimaryHeight)(windowWidth);
    const secondaryWidth = (0, exports.calculateSecondaryWidth)(windowWidth);
    const secondaryHeight = (0, exports.calculateSecondaryHeight)(windowWidth);
    const styles = react_native_1.StyleSheet.create({
        ...baseStyles,
        logo: {
            ...baseStyles.logo,
            width: logoWidth,
            height: logoHeight,
            top: padding,
            left: padding,
        },
        secondary: {
            width: secondaryWidth,
            height: secondaryHeight,
        },
        primary: {
            width: primaryWidth,
            height: primaryHeight,
        },
        primaryChild: {
            padding: padding,
            paddingLeft: 2 * padding,
            paddingRight: padding + logoWidth,
        },
        issuerText: {},
        nameText: {},
        claimText: {},
        status: {
            ...baseStyles.status,
            width: logoWidth,
            height: logoHeight,
        },
    });
    return styles;
};
exports.createStyleSheet = createStyleSheet;
