"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
const ToggleAll_1 = __importDefault(require("../../../../ui/components/detail/body/ToggleAll"));
const contexts_1 = require("../../../../ui/contexts");
const react_i18next_1 = require("react-i18next");
const constants_1 = require("../../../components/detail/constants");
const react_1 = require("react");
const Body = ({ attributes }) => {
    const { t } = (0, react_i18next_1.useTranslation)();
    const { color, text } = (0, contexts_1.useCredentialTheme)();
    const [toggled, setToggled] = (0, react_1.useState)(new Set());
    const styles = react_native_1.StyleSheet.create({
        container: {
            marginHorizontal: constants_1.PADDING_HORIZONTAL,
        },
        labelText: {
            paddingTop: 12,
            paddingBottom: 5,
        },
        value: {
            flexDirection: 'row',
            justifyContent: 'space-between',
            alignItems: 'center',
        },
        valueText: {
            paddingTop: 5,
            paddingBottom: 12,
        },
        border: {
            borderBottomWidth: 2,
            paddingVertical: 10,
            borderColor: color.brand.background,
        },
        borderBottom: {
            borderBottomWidth: 0,
            paddingBottom: 0,
        },
        linkText: {
            color: color.brand.link,
        },
    });
    const toggle = (index) => {
        if (toggled.has(index)) {
            toggled.delete(index);
        }
        else {
            toggled.add(index);
        }
        setToggled(new Set(toggled));
    };
    const toggleAll = () => {
        setToggled(new Set(Array(attributes?.length).keys()));
    };
    const toggleNone = () => {
        toggled.clear();
        setToggled(new Set(toggled));
    };
    return (<react_native_1.FlatList scrollEnabled={false} data={attributes} ListHeaderComponent={() => (<ToggleAll_1.default toggled={!!toggled.size} onToggleAll={(allToggled) => (allToggled ? toggleAll() : toggleNone())}/>)} renderItem={({ item: attribute, index }) => {
            return (<react_native_1.View style={[styles.container, styles.border, index + 1 === attributes?.length ? styles.borderBottom : null]}>
            <react_native_1.View style={styles.value}>
              <react_native_1.Text style={[text.bold, styles.labelText]}>{attribute.formattedLabel}</react_native_1.Text>
              <react_native_1.Pressable 
            // testID={testIdWithKey('ShowHide')}
            style={({ pressed }) => [{ opacity: +!pressed }]} onPress={() => toggle(index)} accessible={true} accessibilityLabel={toggled.has(index) ? t('Detail.Hide') : t('Detail.Show')}>
                <react_native_1.Text style={styles.linkText}>{toggled.has(index) ? t('Detail.Hide') : t('Detail.Show')}</react_native_1.Text>
              </react_native_1.Pressable>
            </react_native_1.View>
            <react_native_1.View>
              <react_native_1.Text style={[text.normal, styles.valueText]}>
                {toggled.has(index) ? attribute.formattedValue : constants_1.HIDDEN_ATTRIBUTE_VALUE}
              </react_native_1.Text>
            </react_native_1.View>
          </react_native_1.View>);
        }}/>);
};
exports.default = Body;
