"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
const Primary_1 = __importDefault(require("../../../components/detail/header/Primary"));
const Secondary_1 = __importDefault(require("../../../components/detail/header/Secondary"));
const Issuer_1 = __importDefault(require("../../../components/common/Issuer"));
const Name_1 = __importDefault(require("../../../components/common/Name"));
const Watermark_1 = __importDefault(require("../../../components/common/Watermark"));
const contexts_1 = require("../../../../ui/contexts");
const utils_1 = require("../../../components/detail/utils");
const utils_2 = require("../../../../utils");
const Logo_1 = __importDefault(require("../../../components/common/Logo"));
const Detail = ({ connectionId, credentialId, credential }) => {
    const { color } = (0, contexts_1.useCredentialTheme)();
    const { width: windowWidth } = (0, react_native_1.useWindowDimensions)();
    let styles = (0, utils_1.createStyleSheet)(windowWidth);
    styles = {
        ...styles,
        primary: {
            ...styles.primary,
            backgroundColor: credential?.primaryBackgroundColor,
        },
        secondary: {
            ...styles.secondary,
            backgroundColor: credential?.secondaryBackgroundColor ?? credential?.primaryBackgroundColor,
            zIndex: +!!(credential?.backgroundImage ?? credential?.secondaryBackgroundColor),
        },
        issuerText: {
            ...styles.issuerText,
            color: (0, utils_2.contrastColor)(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
        },
        nameText: {
            ...styles.nameText,
            color: (0, utils_2.contrastColor)(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
        },
        watermarkText: {
            ...styles.watermarkText,
            color: (0, utils_2.contrastColor)(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.lightGrey),
        },
    };
    return (<react_native_1.View style={styles.container}>
      <Logo_1.default source={credential?.logo} label={credential?.name ?? credential?.issuer ?? credentialId ?? connectionId} style={styles.logo}/>
      <Secondary_1.default source={(0, utils_2.toImageSource)(credential?.backgroundImage)} style={styles.secondary} tint={!(credential?.backgroundImage || credential?.secondaryBackgroundColor)}/>
      <Primary_1.default style={styles.primary}>
        <react_native_1.View style={styles.primaryChild}>
          {/* We keep a default single empty space so the styling remains consistent whether an
          issuer and a name are present */}
          <Issuer_1.default issuer={credential?.issuer ?? connectionId ?? ' '} textStyle={styles.issuerText}/>
          <Name_1.default name={credential?.name ?? credentialId} textStyle={styles.nameText}/>
        </react_native_1.View>
      </Primary_1.default>
      {credential?.watermark && (<Watermark_1.default watermark={credential?.watermark} style={styles.watermark} textStyle={styles.watermarkText}/>)}
    </react_native_1.View>);
};
exports.default = Detail;
