"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.contrastColor = void 0;
const luminance_1 = __importDefault(require("./luminance"));
/**
 * Returns the color that contrasts the most with the given color.
 * @param color The color to contrast.
 * @param shadeDark The color to return if the given color is light.
 * @param shadeLight The color to return if the given color is dark.
 * @param spectrum The color spectrum to use if the shades are not provided.
 * @returns The contrasting color. Defaults to black and white.
 */
const contrastColor = (color = '', shadeDark, shadeLight, spectrum) => {
    const midpoint = 255 / 2;
    if (((0, luminance_1.default)(color) ?? 255) >= midpoint) {
        return shadeDark ?? spectrum?.darkGrey ?? spectrum?.black ?? '#000000';
    }
    return shadeLight ?? spectrum?.lightGrey ?? spectrum?.white ?? '#FFFFFF';
};
exports.contrastColor = contrastColor;
exports.default = exports.contrastColor;
