import { IOverlayBundleData } from '../../interfaces';
import { BaseOverlay, BrandingOverlay, CaptureBase, CharacterEncodingOverlay, FormatOverlay, LabelOverlay, LegacyBrandingOverlay, MetaOverlay, OverlayBundle } from '../../types';
import { Field } from './record';
export declare enum BrandingOverlayType {
    Branding01 = "aries/overlays/branding/0.1",
    Branding10 = "aries/overlays/branding/1.0"
}
export interface CredentialOverlay<T> {
    bundle?: OCABundle;
    presentationFields?: Field[];
    metaOverlay?: MetaOverlay;
    brandingOverlay?: T;
}
export interface OCABundleType {
    get captureBase(): CaptureBase;
    get metaOverlay(): MetaOverlay | undefined;
    get labelOverlay(): LabelOverlay | undefined;
    get formatOverlay(): FormatOverlay | undefined;
    get characterEncodingOverlay(): CharacterEncodingOverlay | undefined;
    get brandingOverlay(): BrandingOverlay | LegacyBrandingOverlay | undefined;
}
export interface OCABundleResolverType {
    resolve(params: {
        identifiers: Identifiers;
        language?: string;
    }): Promise<OCABundle | undefined>;
    resolveDefaultBundle(params: {
        identifiers: Identifiers;
        meeta?: Meta;
        language?: string;
    }): Promise<OCABundle | undefined>;
    presentationFields(params: {
        identifiers: Identifiers;
        attributes: Array<Field>;
        language?: string;
    }): Promise<Field[]>;
    resolveAllBundles(params: {
        identifiers: Identifiers;
        attributes?: Array<Field>;
        meta?: Meta;
        language?: string;
    }): Promise<CredentialOverlay<BaseOverlay | BrandingOverlay | LegacyBrandingOverlay>>;
    getBrandingOverlayType(): BrandingOverlayType;
}
export interface OCABundleResolverOptions {
    language?: string;
    brandingOverlayType?: BrandingOverlayType;
}
export interface Identifiers {
    schemaId?: string;
    credentialDefinitionId?: string;
    templateId?: string;
}
export interface Meta {
    alias?: string;
    credName?: string;
    credConnectionId?: string;
}
export declare class OCABundle implements OCABundleType {
    private bundle;
    private options;
    constructor(bundle: OverlayBundle, options?: OCABundleResolverOptions);
    get captureBase(): CaptureBase;
    get characterEncodingOverlay(): CharacterEncodingOverlay | undefined;
    get formatOverlay(): FormatOverlay | undefined;
    get labelOverlay(): LabelOverlay | undefined;
    get metaOverlay(): MetaOverlay | undefined;
    get brandingOverlay(): BrandingOverlay | LegacyBrandingOverlay | undefined;
    buildOverlay(name: string, language: string): MetaOverlay;
    private getOverlay;
}
export declare class DefaultOCABundleResolver implements OCABundleResolverType {
    protected bundles: Record<string, OverlayBundle | string>;
    protected options: OCABundleResolverOptions;
    private _log?;
    constructor(bundlesData?: Record<string, IOverlayBundleData | string>, options?: OCABundleResolverOptions);
    /**
     * Sets the log value.
     * @param value - The new value for the log.
     */
    set log(value: any);
    /**
     * Get the log value.
     */
    get log(): any;
    getBrandingOverlayType(): BrandingOverlayType;
    private getDefaultBundle;
    resolveDefaultBundle(params: {
        identifiers: Identifiers;
        meta?: Meta;
        language?: string;
    }): Promise<OCABundle | undefined>;
    resolve(params: {
        identifiers: Identifiers;
        language?: string;
    }): Promise<OCABundle | undefined>;
    presentationFields(params: {
        identifiers: Identifiers;
        attributes: Array<Field>;
        language?: string;
    }): Promise<Field[]>;
    resolveAllBundles(params: {
        identifiers: Identifiers;
        attributes?: Array<Field>;
        meta?: Meta;
        language?: string;
    }): Promise<CredentialOverlay<BaseOverlay | BrandingOverlay | LegacyBrandingOverlay>>;
}
