import LocalizedAttribute from './LocalizedAttribute';
export default class LocalizedCredential {
    #bundle;
    attributes;
    issuer;
    name;
    watermark;
    constructor(bundle, record, language) {
        if (!language) {
            throw new Error('language is required');
        }
        this.#bundle = bundle;
        this.issuer = bundle.metadata.issuer?.[language];
        this.name = bundle.metadata.name?.[language];
        this.watermark = bundle.metadata?.watermark?.[language];
        this.attributes = (record.credentialAttributes ?? []).map((attribute) => new LocalizedAttribute(attribute, bundle.getAttribute(attribute.name) ?? { name: attribute.name, type: '' }, language));
    }
    get primaryAttribute() {
        const name = this.#bundle.branding?.primaryAttribute;
        return this.getAttribute(name);
    }
    get secondaryAttribute() {
        const name = this.#bundle.branding?.secondaryAttribute;
        return this.getAttribute(name);
    }
    get logo() {
        return this.#bundle.branding?.logo;
    }
    get primaryBackgroundColor() {
        return this.#bundle.branding?.primaryBackgroundColor;
    }
    get secondaryBackgroundColor() {
        return this.#bundle.branding?.secondaryBackgroundColor;
    }
    get backgroundImage() {
        return this.#bundle.branding?.backgroundImage;
    }
    get backgroundImageSlice() {
        return this.#bundle.branding?.backgroundImageSlice;
    }
    getAttribute(attributeName) {
        if (!attributeName) {
            return undefined;
        }
        return this.attributes.find((attribute) => attribute.name === attributeName);
    }
}
