import { defaultBundleLanguage } from '../constants';
import { OverlayBundle, OverlayType } from '../types';
import { generateColor } from '../utils';
import { parseCredDefFromId } from '../utils/credential-definition';
import startCase from 'lodash.startcase';
export class BaseOverlayBundleResolver {
    _log;
    /**
     * Get the log value.
     */
    get log() {
        return this._log;
    }
    /**
     * Sets the log value.
     * @param value - The new value for the log.
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    set log(value) {
        this._log = value;
    }
}
export class OverlayBundleResolver extends BaseOverlayBundleResolver {
    bundles = {};
    constructor(bundles = {}) {
        super();
        for (const credentialDefinitionId in bundles) {
            const bundle = bundles[credentialDefinitionId];
            try {
                if (typeof bundle === 'string') {
                    this.bundles[credentialDefinitionId] = bundle;
                }
                else {
                    this.bundles[credentialDefinitionId] = new OverlayBundle(credentialDefinitionId, bundle);
                }
            }
            catch (error) {
                this.log?.error(`Error parsing bundle for ${credentialDefinitionId}`, error);
            }
        }
    }
    getDefaultBundle(params) {
        const { identifiers, metadata, language } = params;
        const defaultMetaOverlay = {
            capture_base: '',
            type: OverlayType.Meta10,
            name: metadata?.credentialAlias ??
                startCase(metadata?.credentialId ?? parseCredDefFromId(identifiers?.credentialDefinitionId, identifiers?.schemaId)),
            issuer: metadata?.connectionAlias || metadata?.connectionId || 'Unknown Contact',
            language: language ?? defaultBundleLanguage,
            description: '',
            credential_help_text: '',
            credential_support_url: '',
            issuer_description: '',
            issuer_url: '',
        };
        const colorHash = defaultMetaOverlay?.name ?? defaultMetaOverlay?.issuer ?? 'default';
        const defaultBrandingoOverlay = {
            capture_base: '',
            type: OverlayType.Branding10,
            primary_background_color: generateColor(colorHash)
        };
        const bundle = new OverlayBundle(identifiers?.credentialDefinitionId, {
            capture_base: {
                attributes: {},
                classification: '',
                type: OverlayType.CaptureBase10,
                flagged_attributes: [],
            },
            overlays: [defaultMetaOverlay, defaultBrandingoOverlay],
        });
        return bundle;
    }
    resolveDefaultBundle(params) {
        const bundle = this.getDefaultBundle(params);
        return Promise.resolve(bundle);
    }
    resolveBundle(params) {
        const { identifiers } = params;
        for (const identifier of [identifiers?.credentialDefinitionId, identifiers?.schemaId, identifiers?.templateId]) {
            if (identifier) {
                let bundle = this.bundles[identifier];
                // If it is a string, it is a reference/alias to another one bundle
                if (typeof bundle === 'string') {
                    // Is this guaranteed to be a only one level deep?
                    bundle = this.bundles[bundle];
                }
                return Promise.resolve(bundle);
            }
        }
        return Promise.resolve(undefined);
    }
}
