import { View, useWindowDimensions } from 'react-native';
import { contrastColor, toImageSource } from '../../../utils';
import Issuer from '../../../ui/components/common/Issuer';
import Logo from '../../../ui/components/common/Logo';
import Name from '../../../ui/components/common/Name';
import Status from '../../components/card/Status';
import Watermark from '../../../ui/components/common/Watermark';
import Primary from '../../components/card/body/Primary';
import Secondary from '../../components/card/body/Secondary';
import Claim from '../../components/card/claim/Claim';
import { createStyleSheet } from '../../components/card/utils';
import { useCredentialTheme } from '../../contexts/credentialTheme';
const Card = ({ connectionId, credentialId, status, credential, children }) => {
    const { color } = useCredentialTheme();
    const { width: windowWidth } = useWindowDimensions();
    let styles = createStyleSheet(windowWidth);
    styles = {
        ...styles,
        container: {
            flexDirection: 'row',
            borderRadius: 10,
            ...styles.container,
        },
        primary: {
            ...styles.primary,
            backgroundColor: credential?.primaryBackgroundColor,
        },
        secondary: {
            ...styles.secondary,
            backgroundColor: credential?.secondaryBackgroundColor ?? credential?.primaryBackgroundColor,
            zIndex: +!!(credential?.backgroundImageSlice ?? credential?.secondaryBackgroundColor),
        },
        issuerText: {
            ...styles.issuerText,
            color: contrastColor(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
        },
        nameText: {
            ...styles.nameText,
            color: contrastColor(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
            fontWeight: 'bold',
        },
        claimText: {
            ...styles.claimText,
            color: contrastColor(credential?.primaryBackgroundColor),
        },
        watermarkText: {
            ...styles.watermarkText,
            color: contrastColor(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.lightGrey),
        },
    };
    return (<View style={styles.container}>
      <Logo source={credential?.logo} label={credential?.name ?? credential?.issuer ?? credentialId ?? connectionId} style={styles.logo}/>
      <Secondary source={toImageSource(credential?.backgroundImageSlice)} style={styles.secondary} tint={!(credential?.backgroundImageSlice || credential?.secondaryBackgroundColor)}/>
      <Primary style={styles.primary}>
        <View style={styles.primaryChild}>
          <Issuer issuer={credential?.issuer ?? connectionId} textStyle={styles.issuerText}/>
          <Name name={credential?.name ?? credentialId} textStyle={styles.nameText}/>
          {children ?? (<>
              {credential?.primaryAttribute && (<Claim attribute={credential?.primaryAttribute} textStyle={styles.claimText}/>)}
              {credential?.secondaryAttribute && (<Claim attribute={credential?.secondaryAttribute} textStyle={styles.claimText}/>)}
            </>)}
        </View>
      </Primary>
      {credential?.watermark && (<Watermark watermark={credential?.watermark} style={styles.watermark} textStyle={styles.watermarkText}/>)}
      {status && <Status level={status} style={styles.status}/>}
    </View>);
};
export default Card;
