import { View, StyleSheet } from 'react-native';
import Icon from 'react-native-vector-icons/MaterialIcons';
import { useCredentialTheme } from '../../contexts/credentialTheme';
export var StatusLevelEnum;
(function (StatusLevelEnum) {
    StatusLevelEnum["WARNING"] = "warning";
    StatusLevelEnum["ERROR"] = "error";
})(StatusLevelEnum || (StatusLevelEnum = {}));
const Status = ({ level = undefined, style }) => {
    const { color } = useCredentialTheme();
    const { width, height, position, top, right } = style ?? {};
    const borderRadius = 10;
    const styles = StyleSheet.create({
        container: {
            width,
            height,
            position,
            top,
            right,
            borderTopRightRadius: borderRadius,
            borderBottomLeftRadius: borderRadius,
            justifyContent: 'center',
            alignItems: 'center',
            zIndex: 2,
        },
    });
    const renderStatus = (level) => {
        switch (level) {
            case StatusLevelEnum.WARNING:
                return (<View style={[
                        styles.container,
                        {
                            backgroundColor: color.notification.warn,
                        },
                    ]}>
            <Icon style={{
                        color: color.semantic.warn,
                    }} size={0.7 * width} name={level}/>
          </View>);
            case StatusLevelEnum.ERROR:
                return (<View style={[
                        styles.container,
                        {
                            backgroundColor: color.notification.error,
                        },
                    ]}>
            <Icon style={{
                        color: color.semantic.error,
                    }} size={0.7 * width} name={level}/>
          </View>);
            default:
                return null;
        }
    };
    return (<View>
      {renderStatus(level)}
    </View>);
};
export default Status;
