import { FlatList, Pressable, StyleSheet, Text, View } from 'react-native';
import ShowAll from '../../../../ui/components/detail/body/ToggleAll';
import { useCredentialTheme } from '../../../../ui/contexts';
import { useTranslation } from 'react-i18next';
import { HIDDEN_ATTRIBUTE_VALUE, PADDING_HORIZONTAL } from '../../../components/detail/constants';
import { useState } from 'react';
const Body = ({ attributes }) => {
    const { t } = useTranslation();
    const { color, text } = useCredentialTheme();
    const [toggled, setToggled] = useState(new Set());
    const styles = StyleSheet.create({
        container: {
            marginHorizontal: PADDING_HORIZONTAL,
        },
        labelText: {
            paddingTop: 12,
            paddingBottom: 5,
        },
        value: {
            flexDirection: 'row',
            justifyContent: 'space-between',
            alignItems: 'center',
        },
        valueText: {
            paddingTop: 5,
            paddingBottom: 12,
        },
        border: {
            borderBottomWidth: 2,
            paddingVertical: 10,
            borderColor: color.brand.background,
        },
        borderBottom: {
            borderBottomWidth: 0,
            paddingBottom: 0,
        },
        linkText: {
            color: color.brand.link,
        },
    });
    const toggle = (index) => {
        if (toggled.has(index)) {
            toggled.delete(index);
        }
        else {
            toggled.add(index);
        }
        setToggled(new Set(toggled));
    };
    const toggleAll = () => {
        setToggled(new Set(Array(attributes?.length).keys()));
    };
    const toggleNone = () => {
        toggled.clear();
        setToggled(new Set(toggled));
    };
    return (<FlatList scrollEnabled={false} data={attributes} ListHeaderComponent={() => (<ShowAll toggled={!!toggled.size} onToggleAll={(allToggled) => (allToggled ? toggleAll() : toggleNone())}/>)} renderItem={({ item: attribute, index }) => {
            return (<View style={[styles.container, styles.border, index + 1 === attributes?.length ? styles.borderBottom : null]}>
            <View style={styles.value}>
              <Text style={[text.bold, styles.labelText]}>{attribute.formattedLabel}</Text>
              <Pressable 
            // testID={testIdWithKey('ShowHide')}
            style={({ pressed }) => [{ opacity: +!pressed }]} onPress={() => toggle(index)} accessible={true} accessibilityLabel={toggled.has(index) ? t('Detail.Hide') : t('Detail.Show')}>
                <Text style={styles.linkText}>{toggled.has(index) ? t('Detail.Hide') : t('Detail.Show')}</Text>
              </Pressable>
            </View>
            <View>
              <Text style={[text.normal, styles.valueText]}>
                {toggled.has(index) ? attribute.formattedValue : HIDDEN_ATTRIBUTE_VALUE}
              </Text>
            </View>
          </View>);
        }}/>);
};
export default Body;
