import { View, useWindowDimensions } from 'react-native';
import Primary from '../../../components/detail/header/Primary';
import Secondary from '../../../components/detail/header/Secondary';
import Issuer from '../../../components/common/Issuer';
import Name from '../../../components/common/Name';
import Watermark from '../../../components/common/Watermark';
import { useCredentialTheme } from '../../../../ui/contexts';
import { createStyleSheet } from '../../../components/detail/utils';
import { contrastColor, toImageSource } from '../../../../utils';
import Logo from '../../../components/common/Logo';
const Detail = ({ connectionId, credentialId, credential }) => {
    const { color } = useCredentialTheme();
    const { width: windowWidth } = useWindowDimensions();
    let styles = createStyleSheet(windowWidth);
    styles = {
        ...styles,
        primary: {
            ...styles.primary,
            backgroundColor: credential?.primaryBackgroundColor,
        },
        secondary: {
            ...styles.secondary,
            backgroundColor: credential?.secondaryBackgroundColor ?? credential?.primaryBackgroundColor,
            zIndex: +!!(credential?.backgroundImage ?? credential?.secondaryBackgroundColor),
        },
        issuerText: {
            ...styles.issuerText,
            color: contrastColor(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
        },
        nameText: {
            ...styles.nameText,
            color: contrastColor(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.white),
        },
        watermarkText: {
            ...styles.watermarkText,
            color: contrastColor(credential?.primaryBackgroundColor, color.grayscale.darkGrey, color.grayscale.lightGrey),
        },
    };
    return (<View style={styles.container}>
      <Logo source={credential?.logo} label={credential?.name ?? credential?.issuer ?? credentialId ?? connectionId} style={styles.logo}/>
      <Secondary source={toImageSource(credential?.backgroundImage)} style={styles.secondary} tint={!(credential?.backgroundImage || credential?.secondaryBackgroundColor)}/>
      <Primary style={styles.primary}>
        <View style={styles.primaryChild}>
          {/* We keep a default single empty space so the styling remains consistent whether an
          issuer and a name are present */}
          <Issuer issuer={credential?.issuer ?? connectionId ?? ' '} textStyle={styles.issuerText}/>
          <Name name={credential?.name ?? credentialId} textStyle={styles.nameText}/>
        </View>
      </Primary>
      {credential?.watermark && (<Watermark watermark={credential?.watermark} style={styles.watermark} textStyle={styles.watermarkText}/>)}
    </View>);
};
export default Detail;
