import mulberry32 from './mulberry32';
/**
 * Converts a numerical hash into a hexidecimal color string
 * @see https://helderesteves.com/generating-random-colors-js/#Generating_random_dark_colors
 * @param { number } hash numerical hash value (generated by hashCode function above)
 * @returns { string } hexidecimal string eg. #32d3cc
 */
const hashToRGBA = (hash) => {
    let color = '#';
    const colorRangeUpperBound = 256;
    // once for r, g, b
    for (let i = 0; i < 3; i++) {
        // append a pseudorandom two-char hexidecimal value from the lower half of the color spectrum (to limit to darker colors)
        color += ('0' + Math.floor((mulberry32(hash + i) * colorRangeUpperBound) / 2).toString(16)).slice(-2);
    }
    return color;
};
export default hashToRGBA;
